@@ -1,38 +1,27 @@
 package IO::Socket::Multicast;
 
-use 5.005;
+require 5.005;
 use strict;
-use Carp 'croak';
-use Exporter   ();
-use DynaLoader ();
-use IO::Socket;
-BEGIN {
-  eval "use IO::Interface 0.94 'IFF_MULTICAST';";
-}
 use vars qw(@ISA @EXPORT_OK @EXPORT %EXPORT_TAGS $VERSION);
-BEGIN {
-  my @functions = qw(
-    mcast_add
-    mcast_drop
-    mcast_if
-    mcast_loopback
-    mcast_ttl
-    mcast_dest
-    mcast_send
-  );
-  $VERSION = '1.07_02';
-  @ISA = qw(
-    Exporter
-    DynaLoader
-    IO::Socket::INET
-  );
-  @EXPORT = ( );
-  %EXPORT_TAGS = (
-    'all'       => \@functions,
-    'functions' => \@functions,
-  );
-  @EXPORT_OK = @{ $EXPORT_TAGS{'all'} };
-}
+
+use IO::Socket;
+use Carp 'croak';
+require Exporter;
+require DynaLoader;
+eval <<END; # or warn "IO::Interface module not installed; Cannot use interface names.\n";
+  use IO::Interface 0.94 'IFF_MULTICAST';
+END
+
+my @functions = qw(mcast_add mcast_drop mcast_if mcast_loopback 
+		   mcast_ttl mcast_dest mcast_send);
+
+%EXPORT_TAGS = ('all'       => \@functions,
+		'functions' => \@functions);
+@EXPORT = ( );
+@EXPORT_OK = @{ $EXPORT_TAGS{'all'} };
+
+@ISA = qw(Exporter DynaLoader IO::Socket::INET);
+$VERSION = '1.07';
 
 my $IP = '\d+\.\d+\.\d+\.\d+';
 
@@ -117,11 +106,8 @@ sub mcast_send {
 bootstrap IO::Socket::Multicast $VERSION;
 
 1;
-
 __END__
 
-=pod
-
 =head1 NAME
 
 IO::Socket::Multicast - Send and receive multicast messages
